// -----------------------------------------------------------------------
// Copyright (C) 2019 CERN and copyright holders of VMC Project.
// This software is distributed under the terms of the GNU General Public
// License v3 (GPL Version 3), copied verbatim in the file "LICENSE".
//
// See https://github.com/vmc-project/vmc for full licensing information.
// -----------------------------------------------------------------------

#ifndef TMC_VERSION_H
#define TMC_VERSION_H

/// \file TMCVersion.h
/// \brief Definition of the code version and release date
///
/// \author I. Hrivnacova; IJCLab, Orsay

#define VMC_RELEASE "2.0"
#define VMC_RELEASE_DATE "10 February 2022"

#endif // TMC_VERSION_H
